//========================================================================
// Cinnabar
// Copyright (c) 2016, Pascal Levy
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//========================================================================

#ifndef CINNABAR_H
#define CINNABAR_H

#include <stdint.h>

//--------------------------------------------------------------
// Error codes.
//--------------------------------------------------------------

typedef enum {
    CnbrSuccess             = 0,
    CnbrInvalidParameter,
    CnbrInvalidPrivateKey,
    CnbrInvalidPublicKey,
    CnbrKeyIsTooShort,
    CnbrInvalidSignature,
}
    CnbrStatus;

//--------------------------------------------------------------
// A signature.
//--------------------------------------------------------------

typedef struct _CNBR_SIGNATURE {
    size_t      signature_length;
    uint8_t   * signature_data;
}
    CNBR_SIGNATURE;

//--------------------------------------------------------------

CnbrStatus  CnbrSignature(CNBR_SIGNATURE * signature, const void * document_data, size_t document_length, const char * pem_private_key);
CnbrStatus  CnbrVerifySignature(const uint8_t * signature_data, size_t signature_length, const void * document_data, size_t document_length, const char * pem_public_key);
CnbrStatus  CnbrEraseSignature(CNBR_SIGNATURE * signature);

//--------------------------------------------------------------

#endif

//========================================================================
